@@ -259,10 +259,14 @@ class Campaign:
         id: int,
         name: str,
         send_if_duplicate: bool,
+        has_anniversary_drip: bool = False,
+        has_birthday_drip: bool = False,
     ) -> None:
         self._id = id
         self._name = name
         self._send_if_duplicate = send_if_duplicate
+        self._has_anniversary_drip = has_anniversary_drip
+        self._has_birthday_drip = has_birthday_drip
 
     __repr__ = helpers.repr
 
@@ -281,12 +285,24 @@ class Campaign:
         """If True, AMcards will not attempt to detect and prevent duplicates. Otherwise, if this campaign has been previously sent to a contact, further campaign send attempts to the same contact will be prevented."""
         return self._send_if_duplicate
 
+    @property
+    def has_anniversary_drip(self) -> bool:
+        """True if one of more drips in this campaign are anniversary drips. False otherwise."""
+        return self._has_anniversary_drip
+
+    @property
+    def has_birthday_drip(self) -> bool:
+        """True if one of more drips in this campaign are birthday drips. False otherwise."""
+        return self._has_birthday_drip
+
     @classmethod
     def _from_json(cls, json: dict):
         return cls(
             id=json['id'],
             name=json['title'],
             send_if_duplicate=json['send_even_if_duplicate'],
+            has_anniversary_drip=json['has_anniversary_drip'],
+            has_birthday_drip=json['has_birthday_drip'],
         )
 
 class CardStatus(Enum):
@@ -316,7 +332,7 @@ class Card:
         date_fulfilled: datetime,
         is_international: bool,
         template_name: str,
-        template_url: str,
+        thumbnail: str,
         campaign_id: Optional[int],
         shipping_address: dict,
         return_address: dict,
@@ -331,7 +347,7 @@ class Card:
         self._date_fulfilled = date_fulfilled
         self._is_international = is_international
         self._template_name = template_name
-        self._template_url = template_url
+        self._thumbnail = thumbnail
         self._campaign_id = campaign_id
         self._shipping_address = shipping_address
         self._return_address = return_address
@@ -399,9 +415,9 @@ class Card:
         return self._template_name
 
     @property
-    def template_url(self) -> str:
-        """Url of template for this card."""
-        return self._template_url
+    def thumbnail(self) -> str:
+        """Url of thumbnail for this card."""
+        return self._thumbnail
 
     @property
     def campaign_id(self) -> Optional[int]:
@@ -463,7 +479,7 @@ class Card:
             date_fulfilled=helpers.to_datetime(json['fulfilled']),
             is_international=json['is_international'],
             template_name=json['template_name'],
-            template_url=json['template_url'],
+            thumbnail=json['thumbnail_url'],
             campaign_id=json['campaign_pk'],
             shipping_address=helpers.parse_shipping_address(json),
             return_address=helpers.parse_return_address(json),
